@@ -12,11 +12,12 @@ from hashlib import sha1, md5
 from random import SystemRandom
 from time import time
 
-from rauth.compat import quote, parse_qsl, urljoin, urlsplit, is_basestring
+from rauth.compat import parse_qsl, urljoin, urlsplit, is_basestring
 from rauth.oauth import HmacSha1Signature
-from rauth.utils import (absolute_url, CaseInsensitiveDict, ENTITY_METHODS,
-                         FORM_URLENCODED, get_sorted_params,
-                         OPTIONAL_OAUTH_PARAMS)
+from rauth.utils import (absolute_url, CaseInsensitiveDict,
+                         OAuth1Auth, OAuth2Auth,
+                         ENTITY_METHODS, FORM_URLENCODED,
+                         get_sorted_params, OPTIONAL_OAUTH_PARAMS)
 
 from requests.sessions import Session
 
@@ -179,11 +180,10 @@ class OAuth1Session(RauthSession):
                                 oauth_params,
                                 req_kwargs)
 
-        if header_auth and not 'oauth_signature' in \
+        if header_auth and 'oauth_signature' not in \
                 req_kwargs['headers'].get('Authorization', ''):
-            header = self._get_auth_header(oauth_params, realm)
-            req_kwargs['headers'].update({'Authorization': header})
-        elif entity_method and not 'oauth_signature' in \
+            req_kwargs['auth'] = OAuth1Auth(oauth_params, realm)
+        elif entity_method and 'oauth_signature' not in \
                 (req_kwargs.get('data') or {}):
             req_kwargs['data'] = req_kwargs.get('data') or {}
 
@@ -203,7 +203,7 @@ class OAuth1Session(RauthSession):
             else:
                 req_kwargs.setdefault('params', {})
                 req_kwargs['params'].update(oauth_params)
-        elif not 'oauth_signature' in url:
+        elif 'oauth_signature' not in url:
             req_kwargs.setdefault('params', {})
             req_kwargs['params'].update(oauth_params)
 
@@ -253,15 +253,6 @@ class OAuth1Session(RauthSession):
 
         return oauth_params
 
-    def _get_auth_header(self, oauth_params, realm=None):
-        '''Constructs and returns an authentication header.'''
-        auth_header = 'OAuth realm="{realm}"'.format(realm=realm or '')
-        params = ''
-        for k, v in oauth_params.items():
-            params += ',{key}="{value}"'.format(key=k, value=quote(str(v)))
-        auth_header += params
-        return auth_header
-
 
 class OAuth2Session(RauthSession):
     '''
@@ -295,9 +286,9 @@ class OAuth2Session(RauthSession):
                         params={'format': 'json'})
         print r.json()
 
-    :param client_id: Client id.
+    :param client_id: Client id, defaults to `None`.
     :type client_id: str
-    :param client_secret: Client secret.
+    :param client_secret: Client secret, defaults to `None`
     :type client_secret: str
     :param access_token: Access token, defaults to `None`.
     :type access_token: str
@@ -316,8 +307,8 @@ class OAuth2Session(RauthSession):
                                           'access_token']
 
     def __init__(self,
-                 client_id,
-                 client_secret,
+                 client_id=None,
+                 client_secret=None,
                  access_token=None,
                  service=None,
                  access_token_key=None):
@@ -357,10 +348,7 @@ class OAuth2Session(RauthSession):
             req_kwargs['params'] = dict(parse_qsl(req_kwargs['params']))
 
         if bearer_auth and self.access_token is not None:
-            bearer_token = 'Bearer {token}'.format(token=self.access_token)
-            bearer_header = {'Authorization': bearer_token}
-            req_kwargs.setdefault('headers', {})
-            req_kwargs['headers'].update(bearer_header)
+            req_kwargs['auth'] = OAuth2Auth(self.access_token)
         else:
             req_kwargs['params'].update({self.access_token_key:
                                          self.access_token})
